FILE *res;
t_int rest;
STRING *resty;
size_t restyy;

//Opens filename for reading. If the file does not exist or cannot be found, the fopen_read call fails.
//Return: 0 - successful, -1 failed
DLLFUNC var fopen_read(STRING *filename)
{
	res = fopen(filename->chars, "r");
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Opens an empty file for writing. If the given file exists, its contents are destroyed.
//Return: 0 - successful, -1 failed
DLLFUNC var fopen_write(STRING *filename)
{
	res = fopen(filename->chars, "w");
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Opens for writing at the end of the file (appending) without removing the EOF marker before writing new data to the file; creates the file first if it doesn't exist.
//Return: 0 - successful, -1 failed
DLLFUNC var fopen_append(STRING *filename)
{
	res = fopen(filename->chars, "a");
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Opens for both reading and writing. (The file must exist.)
//Return: 0 - successful, -1 failed
DLLFUNC var fopen_rwrite(STRING *filename)
{
	res = fopen(filename->chars, "r+");
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Opens an empty file for both reading and writing. If the given file exists, its contents are destroyed.
//Return: 0 - successful, -1 failed
DLLFUNC var fopen_rcwrite(STRING *filename)
{
	res = fopen(filename->chars, "w+");
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Opens for reading and appending; the appending operation includes the removal of the EOF marker before new data is written to the file and the EOF marker is restored after writing is complete; creates the file first if it doesn't exist.
//Return: 0 - successful, -1 failed
DLLFUNC var fopen_rappend(STRING *filename)
{
	res = fopen(filename->chars, "a+");
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Closes a stream.
//Return: 0 - successful, -1 failed
DLLFUNC var fclosec()
{
	rest = fclose(res);
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

//Closes all open streams.
//Return: 0 - successful, -1 failed
DLLFUNC var fcloseallc()
{
	rest = _fcloseall();
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

//The feofc routine determines whether the end of stream has been reached.
//Return: 0 - successful, -1 failed
DLLFUNC var feofc()
{
	rest = feof(res);
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

//The ferrorc routine tests for a reading or writing error on the file associated with stream.
//Return: 0 - successful, -1 failed
DLLFUNC var ferrorc()
{
	rest = ferror(res);
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

//Flushes a stream.
//Return: 0 - successful, -1 failed
DLLFUNC var fflushc()
{
	rest = fflush(res);
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

//Reads a single character from the current position of a file.
//Return: character as int - successful, -1 failed
DLLFUNC var fgetcc()
{
	rest = fgetc(res);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Gets a stream's file-position indicator.
//Return: 0 - successful, -1 failed
DLLFUNC var fgetposc(var pos)
{
	rest = fgetpos(res, (fpos_t*)pos);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Reads a STRING from the input stream argument and stores it in STRING.
//Return: STRING - successful, "-1 error" failed
DLLFUNC STRING *fgetsc(STRING *str, var n)
{
	if(strcpy(resty->chars, fgets(str->chars, _INT(n), res)))
		return resty;
	else
		return((STRING*)"NULL");
}

//Gets the file descriptor associated with a stream.
//Return: file descriptor - successful, -1 failed
DLLFUNC var filenoc()
{
	rest = _fileno(res);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Gets the file length in bytes.
//Remarks: Call filenoc() to get fd
//Return: file length - successful, -1 error
DLLFUNC var filelengthc(var fd)
{
	var length = _filelength(_INT(fd));
	if(length)
		return length;
	else
		return _VAR(0);
}

//Flushes all streams; clears all buffers.
//Return: # of open streams - successful, -1 failed
DLLFUNC var flushallc()
{
	rest = _flushall();
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Writes a STRING to a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fprintf_string(STRING *arg)
{
	rest = fprintf(res, "%s", arg->chars);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Writes an asc character to a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fprintf_asc(STRING *arg)
{
	int temp_asc = (int)arg->chars;
	rest = fprintf(res,"%i",temp_asc);
	if(rest)
		return _VAR(rest);
	else
		return -1;
}

//Writes a signed integer to a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fprintf_sint(var arg)
{
	rest = fprintf(res, "%i", _INT(arg));
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Writes an unsigned integer to a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fprintf_uint(var arg)
{
	rest = fprintf(res, "%u", (unsigned int)arg);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Writes a character to a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fprintf_char(STRING *arg)
{
	rest = fprintf(res, "%c", arg->chars);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Writes a floating point to a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fprintf_float(var arg)
{
	rest = fprintf(res, "%f", _FLOAT(arg));
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Allias of fprintf_char.
//Return: character written - successful, -1 failed
DLLFUNC var fputcc(var c)
{
	rest = fputc(_INT(c), res);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Allias of fprintf_STRING.
//Return: 0 - successful, -1 failed
DLLFUNC var fputsc(STRING *str)
{
	rest = fputs(str->chars, res);
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

size_t respy;
//Reads data from a stream.
//Return: # of items read
DLLFUNC var freadc(STRING *buf, var size, var count)
{
	respy = fread(buf->chars, (size_t)size, (size_t)count, res);
	return _VAR((int)respy);
}

//Reassigns a read file pointer.
//Return: 0 - successful, -1 failed
DLLFUNC var freopen_read(STRING *file)
{
	res = freopen(file->chars, "r", res);
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Reassigns a write file pointer.
//Return: 0 - successful, -1 failed
DLLFUNC var freopen_write(STRING *file)
{
	res = freopen(file->chars, "w", res);
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Reassigns an append file pointer.
//Return: 0 - successful, -1 failed
DLLFUNC var freopen_append(STRING *file)
{
	res = freopen(file->chars, "a", res);
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Reassigns a read-write file pointer.
//Return: 0 - successful, -1 failed
DLLFUNC var freopen_rwrite(STRING *file)
{
	res = freopen(file->chars, "r+", res);
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Reassigns an empty read-write file pointer.
//Return: 0 - successful, -1 failed
DLLFUNC var freopen_rcwrite(STRING *file)
{
	res = freopen(file->chars, "w+", res);
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//Reassigns a read-append file pointer.
//Return: 0 - successful, -1 failed
DLLFUNC var freopen_rappend(STRING *file)
{
	res = freopen(file->chars, "a+", res);
	if(res)
		return _VAR(1);
	else
		return _VAR(0);
}

//---------------------------------------------------------//

//Reads a STRING from a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fread_str(STRING *arg)
{
	rest = fscanf(res, "%s", arg->chars);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Reads an asc character from a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fread_asc(STRING *arg)
{
	char *temp_asc = arg->chars;
	rest = fscanf(res,"%i",temp_asc);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Reads a signed integer from a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fread_int(var arg)
{
	rest = fscanf(res, "%i", _INT(arg));
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Reads an unsigned integer from a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fread_uint(var arg)
{
	rest = fscanf(res, "%u", (unsigned int)arg);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Reads a character from a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fread_char(STRING *arg)
{
	rest = fscanf(res, "%c", arg->chars);
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Reads a floating point from a stream.
//Return: # of bytes written - successful, -1 failed
DLLFUNC var fread_float(var arg)
{
	rest = fscanf(res, "%f", _FLOAT(arg));
	if(rest)
		return _VAR(rest);
	else
		return _VAR(0);
}

//Moves the file pointer to the beginning of the stream.
//Return: 0 - successful, -1 failed
DLLFUNC var fseek_start()
{
	rest = fseek(res, 0, SEEK_SET);
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

//Moves the file pointer to the end of the stream.
//Return: 0 - successful, -1 failed
DLLFUNC var fseek_end()
{
	rest = fseek(res, 0, SEEK_END);
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

//Moves the file pointer to the given position from the given current position of the stream.
//Remarks: These must be defined before this function is called:
//#define SEEK_SET 0
//#define SEEK_CUR 1
//#define SEEK_END 2
//Return: 0 - successful, -1 failed
DLLFUNC var fseekc(var offset, var origin)
{
	rest = fseek(res, offset, _INT(origin));
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

//Sets the stream-position indicator.
//Return: 0 - successful, -1 failed
DLLFUNC var fsetposc(var pos)
{
	rest = fsetpos(res, (fpos_t*)pos);
	if(rest)
		return _VAR(1);
	else
		return _VAR(0);
}

long resdy;
//Gets the current position of a file pointer.
//Return: position - successful, -1 failed
DLLFUNC var ftellc()
{
	resdy = ftell(res);
	if(resdy)
		return resdy;
	else
		return _VAR(0);
}

//Writes data to a stream
//Return: 0 - successful, -1 failed
DLLFUNC var fwritec(STRING *data, var size, var count)
{
	restyy = fwrite(data->chars, (size_t)size, (size_t)count, res);
	if(restyy)
		return _VAR(1);
	else
		return _VAR(0);
}